@@ -22,9 +22,9 @@ def general_obj_new(request, Obj, ObjForm, translations={}, \
         cancel_url=False, return_url=False, html_scripts=False, \
         treat_as_list=False, *args, **kwargs):
     """General form view for adding new objects
-    
+
     It' s not a real view, rather a generic function to creating new objects with the predefined parameters:
-    
+
         - name (the name of the Class)
         - callback_prevalidation (method, runs before form validation)
         - callback_postvalidation (method, runs after form validation)
@@ -119,7 +119,7 @@ def general_obj_edit(request, Obj, ObjForm, general_obj_id, querysets=[], \
         callback_postvalidation=False, callback_postaction=False, \
         callback_postsaveaction=False, cancel_url=False, return_url=False):
     """General form view for editing a record of an object
-    
+
         It' s not a real view, rather a generic function to edit objects with the predefined parameters:
 
             - name (the name of the Class)
@@ -205,6 +205,17 @@ def general_obj_bulkedit(request, Obj, ObjForm, general_obj_ids,
         callback_postaction=False, callback_postsaveaction=False, \
         cancel_url=False, return_url=False, label=False, \
         editable_fields=False, allow_redirect_to_edit=True):
+    """General form view for editing a bunch of an objects
+
+        It' s not a real view, rather a generic function to edit more objects at once with the predefined parameters:
+
+            - name (the name of the Class)
+            - general_obj_id (the id of the object)
+            - queryset ()
+            - callback_postvalidation (method, runs after form validation)
+            - callback_postaction (method, runs after saving the object with commit=False)
+            - callback_postsaveaction (method, runs after saving the object)
+            - cancel_url (string, in case of cancel, the user will be redirected to here)"""
     ret_dic = {}
     ret_dic['edit'] = True
     ret_dic['class_name'] = Obj._meta.object_name
@@ -293,6 +304,7 @@ def general_obj_bulkedit(request, Obj, ObjForm, general_obj_ids,
     
 
 def general_obj_delete(request, name, general_obj_id):
+    """General view for deleting an objects by the given ID"""
     try:
         Obj = eval(name)
     except NameError:
@@ -313,11 +325,11 @@ def general_objs(request, Obj, ObjForm, fields=(), query_dict={}, query_term='',
         show_unused_download_excelsheet_button=False, \
         translations_field_names={}, *args, **kwargs):
     """General view for displaying records of an object
-    
+
     It' s not a real view, rather a generic function to displaying filtered list of an Object with a datatable.
-    
+
     The parameters are:
-    
+
         - name (the name of the Class)
         - fields (the fields to be displayed [overrides the default values])
         - query_dict (dictionary for **query)
@@ -426,6 +438,9 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
         allow_overall_search=False, relational_obj_values={}, translations={}, \
         import_instruction_for_obj=False, import_instruction_for_report=False, \
         ajax_url=False, *args, **kwargs):
+    """Generic view for searching objects
+
+    Results can be exported to .xslx files"""
     if not template:
         template = 'generalobj_search.html'
     ret_dic = {}
@@ -451,6 +466,8 @@ def general_obj_search(request, Obj, ObjForm, search_fields=(), \
 def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
         result_fields=(), translations={}, extra_filters={}):
     is_overall_search = request.GET.get('is_overall_search', '')
+    """This view is called mostly by an ajax call, and this is the backend
+    support for the general_obj_search view"""
     (fields, class_name, class_name_lower, ajax_url, charfield_exists, \
             datetimefield_exists, booleanfield_exists) = \
             get_params_for_search(request, Obj, ObjForm, search_fields, \
@@ -540,6 +557,8 @@ def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
 
 
 def download_excelsheet(request):
+    """This view is responsible for generating the excelsheet based on the
+    report file"""
     import_instruction_for_obj = \
             request.GET.get('ge_import_instruction_for_obj', '')
     import_instruction_for_report = \
